==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Nieobecnosc.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.StatusNieobecnosci;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Nieobecnosc extends GenericDPSObject {
    /**
     * NIEOBECNOSC.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * NIEOBECNOSC.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaId;

    /**
     * NIEOBECNOSC.NIEOBECNOSC_INFORMACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long nieobecnoscInformacjaId;

    /**
     * NIEOBECNOSC.RODZAJ_NIEOBECNOSCI_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long rodzajNieobecnosciId;

    /**
     * NIEOBECNOSC.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long szablonWydrukuId;

    /**
     * NIEOBECNOSC.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * NIEOBECNOSC.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * NIEOBECNOSC.LICZBA_DNI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer liczbaDni;

    /**
     * NIEOBECNOSC.LICZBA_DNI_ZWROT
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer liczbaDniZwrot;

    /**
     * NIEOBECNOSC.STATUS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private StatusNieobecnosci status;

    /**
     * NIEOBECNOSC.UWAGI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String uwagi;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return NIEOBECNOSC.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * NIEOBECNOSC.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return NIEOBECNOSC.EWIDENCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * NIEOBECNOSC.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return NIEOBECNOSC.NIEOBECNOSC_INFORMACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getNieobecnoscInformacjaId() {
        return nieobecnoscInformacjaId;
    }

    /**
     * NIEOBECNOSC.NIEOBECNOSC_INFORMACJA_ID
     *
     * @param nieobecnoscInformacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNieobecnoscInformacjaId(Long nieobecnoscInformacjaId) {
        this.nieobecnoscInformacjaId = nieobecnoscInformacjaId;
    }

    /**
     * @return NIEOBECNOSC.RODZAJ_NIEOBECNOSCI_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getRodzajNieobecnosciId() {
        return rodzajNieobecnosciId;
    }

    /**
     * NIEOBECNOSC.RODZAJ_NIEOBECNOSCI_ID
     *
     * @param rodzajNieobecnosciId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzajNieobecnosciId(Long rodzajNieobecnosciId) {
        this.rodzajNieobecnosciId = rodzajNieobecnosciId;
    }

    /**
     * @return NIEOBECNOSC.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * NIEOBECNOSC.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return NIEOBECNOSC.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * NIEOBECNOSC.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return NIEOBECNOSC.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * NIEOBECNOSC.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return NIEOBECNOSC.LICZBA_DNI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getLiczbaDni() {
        return liczbaDni;
    }

    /**
     * NIEOBECNOSC.LICZBA_DNI
     *
     * @param liczbaDni
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setLiczbaDni(Integer liczbaDni) {
        this.liczbaDni = liczbaDni;
    }

    /**
     * @return NIEOBECNOSC.LICZBA_DNI_ZWROT
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getLiczbaDniZwrot() {
        return liczbaDniZwrot;
    }

    /**
     * NIEOBECNOSC.LICZBA_DNI_ZWROT
     *
     * @param liczbaDniZwrot
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setLiczbaDniZwrot(Integer liczbaDniZwrot) {
        this.liczbaDniZwrot = liczbaDniZwrot;
    }

    /**
     * @return NIEOBECNOSC.STATUS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public StatusNieobecnosci getStatus() {
        return status;
    }

    /**
     * NIEOBECNOSC.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStatus(StatusNieobecnosci status) {
        this.status = status;
    }

    /**
     * @return NIEOBECNOSC.UWAGI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getUwagi() {
        return uwagi;
    }

    /**
     * NIEOBECNOSC.UWAGI
     *
     * @param uwagi
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUwagi(String uwagi) {
        this.uwagi = uwagi == null ? null : uwagi.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Nieobecnosc other = (Nieobecnosc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getNieobecnoscInformacjaId() == null ? other.getNieobecnoscInformacjaId() == null : this.getNieobecnoscInformacjaId().equals(other.getNieobecnoscInformacjaId()))
            && (this.getRodzajNieobecnosciId() == null ? other.getRodzajNieobecnosciId() == null : this.getRodzajNieobecnosciId().equals(other.getRodzajNieobecnosciId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getLiczbaDni() == null ? other.getLiczbaDni() == null : this.getLiczbaDni().equals(other.getLiczbaDni()))
            && (this.getLiczbaDniZwrot() == null ? other.getLiczbaDniZwrot() == null : this.getLiczbaDniZwrot().equals(other.getLiczbaDniZwrot()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getUwagi() == null ? other.getUwagi() == null : this.getUwagi().equals(other.getUwagi()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getNieobecnoscInformacjaId() == null) ? 0 : getNieobecnoscInformacjaId().hashCode());
        result = prime * result + ((getRodzajNieobecnosciId() == null) ? 0 : getRodzajNieobecnosciId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getLiczbaDni() == null) ? 0 : getLiczbaDni().hashCode());
        result = prime * result + ((getLiczbaDniZwrot() == null) ? 0 : getLiczbaDniZwrot().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getUwagi() == null) ? 0 : getUwagi().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", nieobecnoscInformacjaId=").append(nieobecnoscInformacjaId);
        sb.append(", rodzajNieobecnosciId=").append(rodzajNieobecnosciId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", liczbaDni=").append(liczbaDni);
        sb.append(", liczbaDniZwrot=").append(liczbaDniZwrot);
        sb.append(", status=").append(status);
        sb.append(", uwagi=").append(uwagi);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Nieobecnosc.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.StatusNieobecnosci;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Nieobecnosc extends GenericDPSObject {
    /**
     * NIEOBECNOSC.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * NIEOBECNOSC.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaId;

    /**
     * NIEOBECNOSC.NIEOBECNOSC_INFORMACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long nieobecnoscInformacjaId;

    /**
     * NIEOBECNOSC.RODZAJ_NIEOBECNOSCI_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long rodzajNieobecnosciId;

    /**
     * NIEOBECNOSC.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long szablonWydrukuId;

    /**
     * NIEOBECNOSC.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * NIEOBECNOSC.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * NIEOBECNOSC.LICZBA_DNI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer liczbaDni;

    /**
     * NIEOBECNOSC.LICZBA_DNI_ZWROT
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer liczbaDniZwrot;

    /**
     * NIEOBECNOSC.STATUS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private StatusNieobecnosci status;

    /**
     * NIEOBECNOSC.UWAGI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String uwagi;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return NIEOBECNOSC.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * NIEOBECNOSC.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return NIEOBECNOSC.EWIDENCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * NIEOBECNOSC.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return NIEOBECNOSC.NIEOBECNOSC_INFORMACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getNieobecnoscInformacjaId() {
        return nieobecnoscInformacjaId;
    }

    /**
     * NIEOBECNOSC.NIEOBECNOSC_INFORMACJA_ID
     *
     * @param nieobecnoscInformacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNieobecnoscInformacjaId(Long nieobecnoscInformacjaId) {
        this.nieobecnoscInformacjaId = nieobecnoscInformacjaId;
    }

    /**
     * @return NIEOBECNOSC.RODZAJ_NIEOBECNOSCI_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getRodzajNieobecnosciId() {
        return rodzajNieobecnosciId;
    }

    /**
     * NIEOBECNOSC.RODZAJ_NIEOBECNOSCI_ID
     *
     * @param rodzajNieobecnosciId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzajNieobecnosciId(Long rodzajNieobecnosciId) {
        this.rodzajNieobecnosciId = rodzajNieobecnosciId;
    }

    /**
     * @return NIEOBECNOSC.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * NIEOBECNOSC.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return NIEOBECNOSC.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * NIEOBECNOSC.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return NIEOBECNOSC.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * NIEOBECNOSC.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return NIEOBECNOSC.LICZBA_DNI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getLiczbaDni() {
        return liczbaDni;
    }

    /**
     * NIEOBECNOSC.LICZBA_DNI
     *
     * @param liczbaDni
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setLiczbaDni(Integer liczbaDni) {
        this.liczbaDni = liczbaDni;
    }

    /**
     * @return NIEOBECNOSC.LICZBA_DNI_ZWROT
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getLiczbaDniZwrot() {
        return liczbaDniZwrot;
    }

    /**
     * NIEOBECNOSC.LICZBA_DNI_ZWROT
     *
     * @param liczbaDniZwrot
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setLiczbaDniZwrot(Integer liczbaDniZwrot) {
        this.liczbaDniZwrot = liczbaDniZwrot;
    }

    /**
     * @return NIEOBECNOSC.STATUS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public StatusNieobecnosci getStatus() {
        return status;
    }

    /**
     * NIEOBECNOSC.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStatus(StatusNieobecnosci status) {
        this.status = status;
    }

    /**
     * @return NIEOBECNOSC.UWAGI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getUwagi() {
        return uwagi;
    }

    /**
     * NIEOBECNOSC.UWAGI
     *
     * @param uwagi
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUwagi(String uwagi) {
        this.uwagi = uwagi == null ? null : uwagi.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Nieobecnosc other = (Nieobecnosc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getNieobecnoscInformacjaId() == null ? other.getNieobecnoscInformacjaId() == null : this.getNieobecnoscInformacjaId().equals(other.getNieobecnoscInformacjaId()))
            && (this.getRodzajNieobecnosciId() == null ? other.getRodzajNieobecnosciId() == null : this.getRodzajNieobecnosciId().equals(other.getRodzajNieobecnosciId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getLiczbaDni() == null ? other.getLiczbaDni() == null : this.getLiczbaDni().equals(other.getLiczbaDni()))
            && (this.getLiczbaDniZwrot() == null ? other.getLiczbaDniZwrot() == null : this.getLiczbaDniZwrot().equals(other.getLiczbaDniZwrot()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getUwagi() == null ? other.getUwagi() == null : this.getUwagi().equals(other.getUwagi()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getNieobecnoscInformacjaId() == null) ? 0 : getNieobecnoscInformacjaId().hashCode());
        result = prime * result + ((getRodzajNieobecnosciId() == null) ? 0 : getRodzajNieobecnosciId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getLiczbaDni() == null) ? 0 : getLiczbaDni().hashCode());
        result = prime * result + ((getLiczbaDniZwrot() == null) ? 0 : getLiczbaDniZwrot().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getUwagi() == null) ? 0 : getUwagi().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", nieobecnoscInformacjaId=").append(nieobecnoscInformacjaId);
        sb.append(", rodzajNieobecnosciId=").append(rodzajNieobecnosciId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", liczbaDni=").append(liczbaDni);
        sb.append(", liczbaDniZwrot=").append(liczbaDniZwrot);
        sb.append(", status=").append(status);
        sb.append(", uwagi=").append(uwagi);
        sb.append("]");
        return sb.toString();
    }
}
